@@ -2,7 +2,6 @@ package Test::RedisClusterImage;
 use warnings;
 use strict;
 use Mouse;
-use namespace::autoclean;
 use Test::Docker::Image::Utility qw(docker);
 
 extends 'Test::Docker::Image';
@@ -11,10 +10,11 @@ my $pid = $$;
 
 sub DESTROY {
     my $self = shift;
-    if ($pid == $$) {
+    if ($pid == $$ && !$ENV{TEST_REDIS_CLUSTER_STARTUP_NODES}) {
         docker($_, $self->container_id)
             for qw/kill rm/;
     }
 }
 
+no Mouse;
 1;
